Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(66)

Unified Diff: chromeos/dbus/shill_device_client.h

Issue 10915106: Renaming instances of "flimflam" with "shill", now that we're only (Closed) Base URL: http://git.chromium.org/chromium/src.git@master
Patch Set: Upload after merge Created 8 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chromeos/dbus/shill_client_unittest_base.cc ('k') | chromeos/dbus/shill_device_client.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chromeos/dbus/shill_device_client.h
diff --git a/chromeos/dbus/flimflam_device_client.h b/chromeos/dbus/shill_device_client.h
similarity index 87%
rename from chromeos/dbus/flimflam_device_client.h
rename to chromeos/dbus/shill_device_client.h
index 46cf00572c9b6892c99ba239c26eca69d6bc5454..ea55b6da238321a287a5d577d8d2ba953e168f15 100644
--- a/chromeos/dbus/flimflam_device_client.h
+++ b/chromeos/dbus/shill_device_client.h
@@ -2,8 +2,8 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#ifndef CHROMEOS_DBUS_FLIMFLAM_DEVICE_CLIENT_H_
-#define CHROMEOS_DBUS_FLIMFLAM_DEVICE_CLIENT_H_
+#ifndef CHROMEOS_DBUS_SHILL_DEVICE_CLIENT_H_
+#define CHROMEOS_DBUS_SHILL_DEVICE_CLIENT_H_
#include <string>
@@ -11,7 +11,7 @@
#include "base/callback.h"
#include "chromeos/chromeos_export.h"
#include "chromeos/dbus/dbus_client_implementation_type.h"
-#include "chromeos/dbus/flimflam_client_helper.h"
+#include "chromeos/dbus/shill_client_helper.h"
namespace base {
@@ -29,20 +29,20 @@ class ObjectPath;
namespace chromeos {
// FlimflamDeviceClient is used to communicate with the Flimflam Device service.
// All methods should be called from the origin thread which initializes the
// DBusThreadManager instance.
-class CHROMEOS_EXPORT FlimflamDeviceClient {
+class CHROMEOS_EXPORT ShillDeviceClient {
public:
- typedef FlimflamClientHelper::PropertyChangedHandler PropertyChangedHandler;
- typedef FlimflamClientHelper::DictionaryValueCallback DictionaryValueCallback;
- typedef FlimflamClientHelper::ErrorCallback ErrorCallback;
+ typedef ShillClientHelper::PropertyChangedHandler PropertyChangedHandler;
+ typedef ShillClientHelper::DictionaryValueCallback DictionaryValueCallback;
+ typedef ShillClientHelper::ErrorCallback ErrorCallback;
- virtual ~FlimflamDeviceClient();
+ virtual ~ShillDeviceClient();
// Factory function, creates a new instance which is owned by the caller.
// For normal usage, access the singleton via DBusThreadManager::Get().
- static FlimflamDeviceClient* Create(DBusClientImplementationType type,
+ static ShillDeviceClient* Create(DBusClientImplementationType type,
dbus::Bus* bus);
// Sets PropertyChanged signal handler.
@@ -142,12 +142,12 @@ class CHROMEOS_EXPORT FlimflamDeviceClient {
protected:
// Create() should be used instead.
- FlimflamDeviceClient();
+ ShillDeviceClient();
private:
- DISALLOW_COPY_AND_ASSIGN(FlimflamDeviceClient);
+ DISALLOW_COPY_AND_ASSIGN(ShillDeviceClient);
};
} // namespace chromeos
-#endif // CHROMEOS_DBUS_FLIMFLAM_DEVICE_CLIENT_H_
+#endif // CHROMEOS_DBUS_SHILL_DEVICE_CLIENT_H_
« no previous file with comments | « chromeos/dbus/shill_client_unittest_base.cc ('k') | chromeos/dbus/shill_device_client.cc » ('j') | no next file with comments »

Powered by Google App Engine
@@ -29,20 +29,20 @@ class ObjectPath;
namespace chromeos {
-// FlimflamDeviceClient is used to communicate with the Flimflam Device service.
+// ShillDeviceClient is used to communicate with the Shill Device service.
// All methods should be called from the origin thread which initializes the
// DBusThreadManager instance.
This is Rietveld 408576698